package com.ynet.life.message;

import com.ynet.gene.component.xml.XMLDocumentLoader;
import com.ynet.gene.data.InvalidArgumentException;
import com.ynet.life.base.Trace;
import java.util.HashMap;
import java.util.Map;
import org.w3c.dom.NamedNodeMap;
import org.w3c.dom.Node;
import org.w3c.dom.NodeList;

/* loaded from: com_ynet_life_message.jar:com/ynet/life/message/MessageConfigXMLReader.class */
public class MessageConfigXMLReader {
    public static Map initializeFrom(String fileName) {
        int type;
        Map messageConfigs = new HashMap();
        try {
            NodeList nodeList = new XMLDocumentLoader().loadXMLDocument(fileName).getDocumentElement().getChildNodes();
            int size = nodeList.getLength();
            for (int i = 0; i < size; i++) {
                Node node = nodeList.item(i);
                if (node.getNodeType() == 1 && "messageConfig".equals(node.getNodeName())) {
                    String businessCode = node.getAttributes().getNamedItem("businessCode").getNodeValue();
                    if (businessCode == null || businessCode.trim().length() == 0) {
                        throw new InvalidArgumentException("businessCode must be set.");
                    }
                    String[] businessCodeArray = businessCode.split(",");
                    String firstBusinessCode = businessCodeArray[0];
                    MessageConfig messageConfig = new MessageConfig(firstBusinessCode);
                    NodeList childs = node.getChildNodes();
                    for (int j = 0; j < childs.getLength(); j++) {
                        Node childNode = childs.item(j);
                        if (childNode.getNodeType() == 1) {
                            if ("fields".equals(childNode.getNodeName())) {
                                NodeList fields = childNode.getChildNodes();
                                for (int k = 0; k < fields.getLength(); k++) {
                                    Node fieldNode = fields.item(k);
                                    if (fieldNode.getNodeType() == 1 && "field".equals(fieldNode.getNodeName())) {
                                        NamedNodeMap fieldAttrs = fieldNode.getAttributes();
                                        Node idNode = fieldAttrs.getNamedItem("id");
                                        if (idNode == null) {
                                            throw new InvalidArgumentException("attribute id must be set in node field.");
                                        }
                                        String id = idNode.getNodeValue();
                                        Node typeNode = fieldAttrs.getNamedItem("type");
                                        if (typeNode == null) {
                                            throw new InvalidArgumentException("attribute type must be set in node field.");
                                        }
                                        Node maskNode = fieldAttrs.getNamedItem("mask");
                                        Node paramCodeNode = fieldAttrs.getNamedItem("paramCode");
                                        Node formatNode = fieldAttrs.getNamedItem("format");
                                        String typeStr = typeNode == null ? null : typeNode.getNodeValue();
                                        boolean mask = maskNode == null ? false : "true".equals(maskNode.getNodeValue());
                                        String paramCode = paramCodeNode == null ? null : paramCodeNode.getNodeValue();
                                        String format = formatNode == null ? null : formatNode.getNodeValue();
                                        if ("account".equals(typeStr)) {
                                            type = 0;
                                        } else if ("amount".equals(typeStr)) {
                                            type = 1;
                                        } else if ("currency".equals(typeStr)) {
                                            type = 2;
                                        } else if ("datetime".equals(typeStr)) {
                                            type = 3;
                                        } else if ("parameter".equals(typeStr)) {
                                            type = 4;
                                        } else {
                                            throw new InvalidArgumentException("attribute type in node field must be a value within account,amount,currency,datetime and parameter.");
                                        }
                                        if (type != 0 && maskNode != null) {
                                            Trace.logInfo("LifeMsg", "attribute mask in node field is omitted when type is not account.");
                                        }
                                        if (type != 3 && formatNode != null) {
                                            Trace.logInfo("LifeMsg", "attribute format in node field is omitted when type is not datetime.");
                                        }
                                        if (type != 4 && paramCodeNode != null) {
                                            Trace.logInfo("LifeMsg", "attribute paramCode in node field is omitted when type is not parameter.");
                                        }
                                        messageConfig.addField(id, type, mask, paramCode, format);
                                    }
                                }
                            } else if ("formats".equals(childNode.getNodeName())) {
                                NodeList formatsNodeList = childNode.getChildNodes();
                                for (int k2 = 0; k2 < formatsNodeList.getLength(); k2++) {
                                    Node formatNode2 = formatsNodeList.item(k2);
                                    NamedNodeMap formatAttrs = formatNode2.getAttributes();
                                    if (formatNode2.getNodeType() == 1 && "format".equals(formatNode2.getNodeName())) {
                                        Node idNode2 = formatAttrs.getNamedItem("id");
                                        if (idNode2 == null) {
                                            throw new InvalidArgumentException("attribute id must be set in node format.");
                                        }
                                        Node languageNode = formatAttrs.getNamedItem("language");
                                        String id2 = idNode2.getNodeValue();
                                        String language = languageNode == null ? null : languageNode.getNodeValue();
                                        String format2 = formatNode2.getFirstChild().getNodeValue();
                                        messageConfig.addFormat(id2, language, format2);
                                    }
                                }
                            } else {
                                continue;
                            }
                        }
                    }
                    messageConfigs.put(firstBusinessCode, messageConfig);
                    for (int j2 = 1; j2 < businessCodeArray.length; j2++) {
                        MessageConfig newMessageConfig = messageConfig.quickCopy(businessCodeArray[j2]);
                        messageConfigs.put(businessCodeArray[j2], newMessageConfig);
                    }
                }
            }
            Trace.logInfo("LifeMsg", "Initialize message configs from " + fileName + " OK!");
        } catch (Exception e) {
            Trace.logError("LifeMsg", "Initialize message configs from " + fileName + " failed.", e);
        }
        return messageConfigs;
    }
}
